==> haskell-cryptohash-sha1-0.11.101.0-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-sha1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-sha1
version:              0.11.101.0
visibility:           public
id:                   cryptohash-sha1-0.11.101.0-KGcONWtTIAvBOF07WM1nkj
key:                  cryptohash-sha1-0.11.101.0-KGcONWtTIAvBOF07WM1nkj
license:              BSD-3-Clause
copyright:            Vincent Hanquez, Herbert Valerio Riedel
maintainer:           Herbert Valerio Riedel <hvr@gnu.org>
homepage:             https://github.com/hvr/cryptohash-sha1
synopsis:             Fast, pure and practical SHA-1 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/SHA-1 SHA-1 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.

    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.

    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package has been
    deprecated and so this package continues to satisfy the need for a lightweight package
    providing the SHA1 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.

    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.SHA1" module, though with a clearly smaller footprint.

category:             Data, Cryptography
abi:                  e98052ad1f5c2beba4fe2aa072b4ea4b
exposed:              True
exposed-modules:      Crypto.Hash.SHA1
hidden-modules:       Crypto.Hash.SHA1.FFI Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cryptohash-sha1-0.11.101.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cryptohash-sha1-0.11.101.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptohash-sha1
hs-libraries:         HScryptohash-sha1-0.11.101.0-KGcONWtTIAvBOF07WM1nkj
depends:              base-4.16.4.0 bytestring-0.11.4.0
haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-sha1/html/cryptohash-sha1.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-sha1/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-sha1-0.11.101.0-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-sha1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-sha1
version:              0.11.101.0
visibility:           public
id:                   cryptohash-sha1-0.11.101.0-9Zk40MHp9eRKJkzFHk0IQ6
key:                  cryptohash-sha1-0.11.101.0-9Zk40MHp9eRKJkzFHk0IQ6
license:              BSD-3-Clause
copyright:            Vincent Hanquez, Herbert Valerio Riedel
maintainer:           Herbert Valerio Riedel <hvr@gnu.org>
homepage:             https://github.com/hvr/cryptohash-sha1
synopsis:             Fast, pure and practical SHA-1 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/SHA-1 SHA-1 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.

    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.

    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package has been
    deprecated and so this package continues to satisfy the need for a lightweight package
    providing the SHA1 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.

    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.SHA1" module, though with a clearly smaller footprint.

category:             Data, Cryptography
abi:                  ea732bbe14aa5ce9710e982933f1ea69
exposed:              True
exposed-modules:      Crypto.Hash.SHA1
hidden-modules:       Crypto.Hash.SHA1.FFI Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cryptohash-sha1-0.11.101.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cryptohash-sha1-0.11.101.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptohash-sha1
hs-libraries:         HScryptohash-sha1-0.11.101.0-9Zk40MHp9eRKJkzFHk0IQ6
depends:              base-4.16.4.0 bytestring-0.11.4.0
haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-sha1/html/cryptohash-sha1.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-sha1/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
